
BaseUrl='https://Openapi.5paisa.com/VendorsAPI/Service1.svc/'



LOGIN_ROUTE = f'{BaseUrl}V4/LoginRequestMobileNewbyEmail'

MARGIN_ROUTE = f'{BaseUrl}V3/Margin'
ORDER_BOOK_ROUTE = f'{BaseUrl}V2/OrderBook'
HOLDINGS_ROUTE = f'{BaseUrl}V2/Holding'
POSITIONS_ROUTE = f'{BaseUrl}V1/NetPositionNetWise'

ORDER_PLACEMENT_ROUTE = f'{BaseUrl}PlaceOrderRequest'
ORDER_MODIFY_ROUTE= f'{BaseUrl}ModifyOrderRequest'
ORDER_CANCEL_ROUTE= f'{BaseUrl}CancelOrderRequest'
ORDER_STATUS_ROUTE = f'{BaseUrl}V1/OrderStatus'
TRADE_INFO_ROUTE = f'{BaseUrl}TradeInformation'

BRACKET_MOD_ROUTE= f'{BaseUrl}ModifySMOOrder'
BRACKET_ORDER_ROUTE= f'{BaseUrl}SMOOrderRequest'

MARKET_FEED_ROUTE= f'{BaseUrl}MarketFeed'
LOGIN_CHECK_ROUTE="https://openfeed.5paisa.com/Feeds/api/UserActivity/LoginCheck"

MARKET_DEPTH_ROUTE= f'{BaseUrl}MarketDepth'
JWT_VALIDATION_ROUTE="https://Openapi.indiainfoline.com/VendorsAPI/Service1.svc/JWTOpenApiValidation"
HISTORICAL_DATA_ROUTE="https://openapi.5paisa.com/historical/"

IDEAS_ROUTE= f'{BaseUrl}TraderIDEAs'

TRADEBOOK_ROUTE= f'{BaseUrl}V1/TradeBook'
